==> eg_particle_interactions-v0.8.4-fabric-mc1.21.8-sources.jar: games/enchanted/eg_particle_interactions/common/util/TextureHelpers.java <==
package games.enchanted.eg_particle_interactions.common.util;

import games.enchanted.eg_particle_interactions.common.ParticleInteractionsMod;
import games.enchanted.eg_particle_interactions.common.resource.ParticlePaletteAtlasManager;
import net.minecraft.class_1047;
import net.minecraft.class_1058;
import net.minecraft.class_1059;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import org.jetbrains.annotations.NotNull;
//? if minecraft: > 1.21.8 {
/*import net.minecraft.data.AtlasIds;
*///?}

public class TextureHelpers {
    public static @NotNull class_1059 getTextureAtlas(class_2960 atlasLocation) {
        return class_310.method_1551()
            //? if minecraft: <= 1.21.8 {
            .method_1554().method_24153(atlasLocation);
            //?} else {
            /*.getAtlasManager().getAtlasOrThrow(atlasLocation);
            *///?}
    }

    public static class_1058 getSpriteFromBlockAtlas(class_2960 location) {
        return getTextureAtlas(getBlocksAtlasID()).method_4608(location);
    }

    public static class_1058 getDebugSprite() {
        return getSpriteFromBlockAtlas(class_2960.method_60656("block/debug"));
    }

    public static class_1058 getParticlePaletteSprite(class_2960 location) {
        //? if minecraft: <= 1.21.8 {
        return ParticleInteractionsMod.particlePaletteAtlas.get(location);
        //?} else {
        /*return getTextureAtlas(ParticlePaletteAtlasManager.ATLAS_ID).getSprite(location);
        *///?}
    }

    public static class_1058 getParticlePaletteOrBlockSprite(class_2960 blockLocation, class_2960 fallbackSpriteLocation) {
        class_1058 particlePaletteSprite = getParticlePaletteSprite(blockLocation);
        if(particlePaletteSprite.method_45851().method_45816() == class_1047.method_4539()) {
            return getTextureAtlas(getBlocksAtlasID()).method_4608(fallbackSpriteLocation);
        }
        return particlePaletteSprite;
    }

    public static class_2960 getBlocksAtlasID() {
        //? if minecraft: <= 1.21.8 {
        return class_1059.field_5275;
         //?} else {
        /*return AtlasIds.BLOCKS;
        *///?}
    }
}

==> eg_particle_interactions-v0.8.5-fabric-mc1.21.10-sources.jar: games/enchanted/eg_particle_interactions/common/util/TextureHelpers.java <==
package games.enchanted.eg_particle_interactions.common.util;

import games.enchanted.eg_particle_interactions.common.ParticleInteractionsMod;
import org.jetbrains.annotations.NotNull;
import games.enchanted.eg_particle_interactions.common.resource.ParticlePaletteAtlasManager;
//?}
import net.minecraft.class_1047;
import net.minecraft.class_1058;
import net.minecraft.class_1059;
import net.minecraft.class_10725;
import net.minecraft.class_2960;
import net.minecraft.class_310;

public class TextureHelpers {
    public static @NotNull class_1059 getTextureAtlas(class_2960 atlasLocation) {
        return class_310.method_1551()
            //? if minecraft: <= 1.21.8 {
            /*.getModelManager().getAtlas(atlasLocation);
            *///?} else {
            .method_72703().method_73025(atlasLocation);
            //?}
    }

    public static class_1058 getSpriteFromBlockAtlas(class_2960 location) {
        return getTextureAtlas(getBlocksAtlasID()).method_4608(location);
    }

    public static class_1058 getDebugSprite() {
        return getSpriteFromBlockAtlas(class_2960.method_60656("block/debug"));
    }

    public static class_1058 getParticlePaletteSprite(class_2960 location) {
        //? if minecraft: <= 1.21.8 {
        /*return ParticleInteractionsMod.particlePaletteAtlas.get(location);
        *///?} else {
        return getTextureAtlas(ParticlePaletteAtlasManager.ATLAS_ID).method_4608(location);
        //?}
    }

    public static class_1058 getParticlePaletteOrBlockSprite(class_2960 blockLocation, class_2960 fallbackSpriteLocation) {
        class_1058 particlePaletteSprite = getParticlePaletteSprite(blockLocation);
        if(particlePaletteSprite.method_45851().method_45816() == class_1047.method_4539()) {
            return getTextureAtlas(getBlocksAtlasID()).method_4608(fallbackSpriteLocation);
        }
        return particlePaletteSprite;
    }

    public static class_2960 getBlocksAtlasID() {
        //? if minecraft: <= 1.21.8 {
        /*return TextureAtlas.LOCATION_BLOCKS;
         *///?} else {
        return class_10725.field_56382;
        //?}
    }
}
